;;; ob-pikchr.el --- org-babel support for pikchar evaluation

;;; Code:
(require 'ob)
(require 'ob-eval)

(defvar org-babel-default-header-args:pikchr
  '((:results . "file") (:exports . "results"))
  "Default arguments for evaluating a pikchr source block.")

(defcustom org-pikchr-path nil
  "Path to pikchr executable"
  :group 'org-babel
  :type 'string)

(defun org-babel-execute:pikchr (body params)
  "Execute a block of pikchr code with org-babel.
This function is called by `org-babel-execute-src-block'."
  (let* ((result-params (split-string (or (cdr (assoc :results params)) "")))
	 (out-file (or (cdr (assoc :file params))
		       (error "Pikchr requires a \":file\" header argument")))
	 (cmdline (cdr (assoc :cmdline params)))
	 (in-file (org-babel-temp-file "pikchr-"))
	 (cmd (if (not org-pikchr-path)
		  (error "`org-pikchr-path' is not set")
		(concat (shell-quote-argument
			 (expand-file-name org-pikchr-path))
			" --svg-only " cmdline
			(org-babel-process-file-name in-file)
			" > "
			(org-babel-process-file-name out-file)))))
    (unless (file-exists-p org-pikchr-path)
      (error "Could not find pikchr at %s" org-pikchr-path))
    (with-temp-file in-file (insert body))
    (message "%s" cmd) (org-babel-eval cmd "")
    nil))

(defun org-babel-prep-session:pikchr (session params)
  "Return an error because pikchr does not support sessions."
  (error "Pikchr does not support sessions"))


(provide 'ob-pikchr)

;;; ob-pikchar.el ends here
